parse_model: Parse the model specification for specials

View source: R/parse.R

parse_modelR Documentation

Parse the model specification for specials

Description

Using a list of defined special functions, the user's formula specification and data is parsed to extract important modelling components.

Usage

parse_model(model)

Arguments

model

A model definition


fabletools documentation built on Feb. 9, 2026, 5:06 p.m.