| components.mdl_df | R Documentation |
Allows you to extract elements of interest from the model which can be useful in understanding how they contribute towards the overall fitted values.
## S3 method for class 'mdl_df'
components(object, ...)
## S3 method for class 'mdl_ts'
components(object, ...)
object |
A mable. |
... |
Other arguments passed to methods. |
A dable will be returned, which will allow you to easily plot the components and see the way in which components are combined to give forecasts.
The components can also be visualised using the autoplot() method provided
by the ggtime package.
library(fable)
library(tsibbledata)
# Forecasting with an ETS(M,Ad,A) model to Australian beer production
aus_production %>%
model(ets = ETS(log(Beer) ~ error("M") + trend("Ad") + season("A"))) %>%
components()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.