| model_combination_ops | R Documentation |
These methods allow multiple fitted models to be combined into a single
joint combination model. Unlike the pairwise arithmetic approach (e.g.
(m1 + m2 + m3)/3), these solve the N-way convolution of all component
distributions simultaneously using the full residual covariance matrix,
so the result is invariant to the order in which models are listed.
## S3 method for class 'mdl_ts'
Summary(..., na.rm = FALSE)
## S3 method for class 'mdl_ts'
mean(x, ...)
## S3 method for class 'mdl_ts'
weighted.mean(x, w, ...)
## S3 method for class 'mdl_lst'
Summary(..., na.rm = FALSE)
## S3 method for class 'mdl_lst'
mean(x, ...)
## S3 method for class 'mdl_lst'
weighted.mean(x, w, ...)
... |
Additional models to include in the combination. |
na.rm |
Ignored; present for compatibility with the |
x |
The first model (or a list/ |
w |
A numeric vector of weights, one per model (will be normalised to sum to 1). |
A fitted combination model (mdl_ts) of class model_combination.
combination_ensemble(), combination_weighted()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.